<?php
/*
 * Elementor Consult Blog Widget
 * Author & Copyright: helloexpert
*/

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Consult_Blog extends Widget_Base{

	/**
	 * Retrieve the widget name.
	*/
	public function get_name(){
		return 'hx-consult_blog';
	}

	/**
	 * Retrieve the widget title.
	*/
	public function get_title(){
		return esc_html__( 'Blog', 'consult' );
	}

	/**
	 * Retrieve the widget icon.
	*/
	public function get_icon() {
		return 'fa fa-newspaper-o';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	*/
	public function get_categories() {
		return ['consult-elements'];
	}

	/**
	 * Retrieve the list of scripts the Consult Blog widget depended on.
	 * Used to set scripts dependencies required to run the widget.
	*/
	public function get_script_depends() {
		return ['hx-consult_blog'];
	}
	
	/**
	 * Register Consult Blog widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	*/
	protected function _register_controls(){

		$posts = get_posts( 'post_type="post"&numberposts=-1' );
    $PostID = array();
    if ( $posts ) {
      foreach ( $posts as $post ) {
        $PostID[ $post->ID ] = $post->ID;
      }
    } else {
      $PostID[ esc_html__( 'No ID\'s found', 'consult' ) ] = 0;
    }
		
		$this->start_controls_section(
			'section_blog_metas',
			[
				'label' => esc_html__( 'Meta\'s Options', 'consult' ),
			]
		);
		$this->add_control(
			'blog_image',
			[
				'label' => esc_html__( 'Image', 'consult' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'consult' ),
				'label_off' => esc_html__( 'Hide', 'consult' ),
				'return_value' => 'true',
				'default' => 'true',
			]
		);
		$this->add_control(
			'blog_date',
			[
				'label' => esc_html__( 'Date', 'consult' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'consult' ),
				'label_off' => esc_html__( 'Hide', 'consult' ),
				'return_value' => 'true',
				'default' => 'true',
			]
		);
		$this->add_control(
			'blog_author',
			[
				'label' => esc_html__( 'Author', 'consult' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'consult' ),
				'label_off' => esc_html__( 'Hide', 'consult' ),
				'return_value' => 'true',
				'default' => 'true',
			]
		);
		$this->add_control(
			'blog_comments',
			[
				'label' => esc_html__( 'Comments', 'consult' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'consult' ),
				'label_off' => esc_html__( 'Hide', 'consult' ),
				'return_value' => 'true',
				'default' => 'true',
			]
		);
		$this->add_control(
			'blog_tags',
			[
				'label' => esc_html__( 'Tags', 'consult' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'consult' ),
				'label_off' => esc_html__( 'Hide', 'consult' ),
				'return_value' => 'true',
				'default' => 'true',
			]
		);
		$this->add_control(
			'read_more_txt',
			[
				'label' => esc_html__( 'Read More Text', 'consult' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
				'placeholder' => esc_html__( 'Type your Read More text here', 'consult' ),
			]
		);
		$this->end_controls_section();// end: Section


		$this->start_controls_section(
			'section_blog_listing',
			[
				'label' => esc_html__( 'Listing Options', 'consult' ),
			]
		);
		$this->add_control(
			'blog_limit',
			[
				'label' => esc_html__( 'Blog Limit', 'consult' ),
				'type' => Controls_Manager::NUMBER,
				'min' => 1,
				'max' => 100,
				'step' => 1,
				'default' => 3,
				'description' => esc_html__( 'Enter the number of items to show.', 'consult' ),
			]
		);
		$this->add_control(
			'blog_order',
			[
				'label' => esc_html__( 'Order', 'consult' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'ASC' => esc_html__( 'Asending', 'consult' ),
					'DESC' => esc_html__( 'Desending', 'consult' ),
				],
				'default' => 'DESC',
			]
		);
		$this->add_control(
			'blog_orderby',
			[
				'label' => esc_html__( 'Order By', 'consult' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'none' => esc_html__( 'None', 'consult' ),
					'ID' => esc_html__( 'ID', 'consult' ),
					'author' => esc_html__( 'Author', 'consult' ),
					'title' => esc_html__( 'Title', 'consult' ),
					'date' => esc_html__( 'Date', 'consult' ),
				],
				'default' => 'date',
			]
		);
		$this->add_control(
			'blog_show_id',
			[
				'label' => esc_html__( 'Certain ID\'s?', 'consult' ),
				'type' => Controls_Manager::SELECT2,
				'default' => [],
				'options' => $PostID,
				'multiple' => true,
			]
		);
		$this->add_control(
			'short_content',
			[
				'label' => esc_html__( 'Excerpt Length', 'consult' ),
				'type' => Controls_Manager::NUMBER,
				'min' => 1,
				'step' => 1,
				'default' => 55,
				'description' => esc_html__( 'How many words you want in short content paragraph.', 'consult' ),
			]
		);
		$this->end_controls_section();// end: Section

		
		// Title
		$this->start_controls_section(
			'section_title_style',
			[
				'label' => esc_html__( 'Title', 'consult' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Color', 'consult' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .blog-section h3 a,.blog-pg-section .post h3 a,.blog-pg-section .entry-meta li a,.blog-pg-section .entry-meta li' => 'color: {{VALUE}};'
				],
			]
		);
		$this->add_control(
			'title_padding',
			[
				'label' => esc_html__( 'Title Padding', 'consult' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .blog-section h3 a,.blog-pg-section .post h3 a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		// Meta
		$this->start_controls_section(
			'section_meta_style',
			[
				'label' => esc_html__( 'Meta', 'consult' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'consult' ),
				'name' => 'sasban_meta_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .blog-section .entry-meta ul li, .blog-section .entry-meta ul li a,.blog-pg-section .entry-meta li',
			]
		);
		$this->add_control(
			'meta_color',
			[
				'label' => esc_html__( 'Color', 'consult' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .blog-section .entry-meta ul li, .blog-pg-section .entry-meta li a,.blog-pg-section .entry-meta li, .blog-section .entry-media .tag' => 'color: {{VALUE}};',
					'{{WRAPPER}} .blog-section .entry-meta ul > li + li:before,.blog-pg-section .entry-meta:before' => 'background-color: {{VALUE}};'
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'blog_meta_bg_color',
				'label' => esc_html__( 'Background', 'consult' ),
				'types' => [ 'gradient' ],
				'selector' => '{{WRAPPER}} .blog-section .entry-media .tag',
			]
		);
		$this->add_control(
			'meta_padding',
			[
				'label' => esc_html__( 'Title Padding', 'consult' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .blog-section .entry-meta ul li,.blog-section .entry-meta ul li a,.blog-pg-section .entry-meta li' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();// end: Section


		// Button
		$this->start_controls_section(
			'section_button_style',
			[
				'label' => esc_html__( 'Button', 'consult' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
	
		$this->add_control(
			'button_color',
			[
				'label' => esc_html__( 'Color', 'consult' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .blog-pg-section a.theme-btn' => 'color: {{VALUE}};'
				],
			]
		);
		
		$this->add_control(
			'button_bg_color',
			[
				'label' => esc_html__( 'Background Color', 'consult' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .blog-pg-section a.theme-btn' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .blog-pg-section a.theme-btn:after' => 'border-color: {{VALUE}};'
				],
			]
		);
		
		$this->end_controls_section();// end: Section

		
	}

	/**
	 * Render Blog widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	*/
	protected function render() {
		$settings = $this->get_settings_for_display();

		$read_more_txt = !empty( $settings['read_more_txt'] ) ? $settings['read_more_txt'] : '';

		$blog_limit = !empty( $settings['blog_limit'] ) ? $settings['blog_limit'] : '';
		$blog_image  = ( isset( $settings['blog_image'] ) && ( 'true' == $settings['blog_image'] ) ) ? true : false;
		$blog_date  = ( isset( $settings['blog_date'] ) && ( 'true' == $settings['blog_date'] ) ) ? true : false;
		$blog_author  = ( isset( $settings['blog_author'] ) && ( 'true' == $settings['blog_author'] ) ) ? true : false;
		$blog_comments  = ( isset( $settings['blog_comments'] ) && ( 'true' == $settings['blog_comments'] ) ) ? true : false;
		$blog_tags  = ( isset( $settings['blog_tags'] ) && ( 'true' == $settings['blog_tags'] ) ) ? true : false;

		$blog_order = !empty( $settings['blog_order'] ) ? $settings['blog_order'] : '';
		$blog_orderby = !empty( $settings['blog_orderby'] ) ? $settings['blog_orderby'] : '';
		$blog_show_id = !empty( $settings['blog_show_id'] ) ? $settings['blog_show_id'] : [];
		$short_content = !empty( $settings['short_content'] ) ? $settings['short_content'] : '';
	
		$excerpt_length = $short_content ? $short_content : '14';
		$read_more_txt = $read_more_txt ? $read_more_txt : esc_html__( 'Read More', 'consult' );

	
		// Turn output buffer on
		ob_start();


    if ($blog_show_id) {
			$blog_show_id = json_encode( $blog_show_id );
			$blog_show_id = str_replace(array( '[', ']' ), '', $blog_show_id);
			$blog_show_id = str_replace(array( '"', '"' ), '', $blog_show_id);
      $blog_show_id = explode(',',$blog_show_id);
    } else {
      $blog_show_id = '';
    }

		$args = array(
		  // other query params here,
		  'post_type' => 'post',
		  'posts_per_page' => (int)$blog_limit,
		  'orderby' => $blog_orderby,
		  'order' => $blog_order,
      'post__in' => $blog_show_id,
		);

		$consult_post = new \WP_Query( $args ); ?>

			
		<div class="blog-section">
	    <div class="blog-grids">
	        
	        <?php 
					  if ($consult_post->have_posts()) : while ($consult_post->have_posts()) : $consult_post->the_post();
					  $large_image =  wp_get_attachment_image_src( get_post_thumbnail_id(get_the_ID()), 'fullsize', false, '' );
					  $large_alt = get_post_meta( get_post_thumbnail_id(get_the_ID()) , '_wp_attachment_image_alt', true); 
					  $large_image = $large_image[0];  

				  ?>
	        <div class="grid">
	            <div class="entry-media">
	            	<?php if ( $large_image ) { ?>
			              <img src="<?php echo esc_url( $large_image ); ?>" alt="<?php echo esc_attr( $large_alt ); ?>">
	           		<?php } ?>
	           		<?php if ( $blog_date ) { ?>
									<div class="date">
						          <p><?php echo get_the_date('M'); ?><span><?php echo get_the_date('d'); ?></span></p>
						      </div>
								<?php	} ?>
	            </div>
	            <div class="entry-details">
	               <h3><a href="<?php echo esc_url( get_permalink() ); ?>"><?php echo esc_html(get_the_title()); ?></a></h3>
	                <div class="entry-meta clearfix">
	                    <ul>
	                       <?php if ( $blog_author ) { ?>
												  <li>
													<i class="ti-user"></i>
													 <?php
															printf( esc_html__(' By:','consult') .' <a href="%1$s" rel="author">%2$s</a>',
														esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
														get_the_author()
													 ); 
													?>
												  </li>
												<?php } ?>
												<?php	if ( $blog_comments ) { ?>
													  <li>
															 <a class="consult-comment" href="<?php echo esc_url( get_comments_link() ); ?>">
																<i class="ti-comment-alt"></i>
														<?php printf( esc_html( _nx( 'Comment (%1$s)', 'Comments (%1$s)', get_comments_number(), 'comments title', 'consult' ) ), '<span class="comment">'.number_format_i18n( get_comments_number() ).'</span>','<span>' . get_the_title() . '</span>' ); ?>
													</a>
												  </li>
												<?php	} ?>
	                    </ul>
	                </div>
	            </div>
	        </div>
	        <?php 
					  endwhile;
					  endif;
					  wp_reset_postdata(); ?>
	    </div>
		</div>

		<?php
			// Return outbut buffer
			echo ob_get_clean();	
		}
	
}