<?php
/*
 * Elementor Consult Project Widget
 * Author & Copyright: helloexpert
*/

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Consult_Project extends Widget_Base{

	/**
	 * Retrieve the widget name.
	*/
	public function get_name(){
		return 'hx-consult_project';
	}

	/**
	 * Retrieve the widget title.
	*/
	public function get_title(){
		return esc_html__( 'Project', 'consult' );
	}

	/**
	 * Retrieve the widget icon.
	*/
	public function get_icon() {
		return 'fa fa-file-signature';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	*/
	public function get_categories() {
		return ['consult-elements'];
	}

	/**
	 * Retrieve the list of scripts the Consult Project widget depended on.
	 * Used to set scripts dependencies required to run the widget.
	*/
	public function get_script_depends() {
		return ['hx-consult_project'];
	}
	
	/**
	 * Register Consult Project widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	*/
	protected function _register_controls(){
		
		$this->start_controls_section(
			'section_project',
			[
				'label' => esc_html__( 'Project Options', 'consult' ),
			]
		);
		$repeater = new Repeater();
		$repeater->add_control(
			'project_image',
			[
				'label' => esc_html__( 'Project Image', 'consult' ),
				'type' => Controls_Manager::MEDIA,
				'frontend_available' => true,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'description' => esc_html__( 'Set your image.', 'consult'),
			]
		);
		$repeater->add_control(
			'project_title',
			[
				'label' => esc_html__( 'Title Text', 'consult' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Title Text', 'consult' ),
				'placeholder' => esc_html__( 'Type title text here', 'consult' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'project_content',
			[
				'label' => esc_html__( 'Content', 'consult' ),
				'default' => esc_html__( 'your content text', 'consult' ),
				'placeholder' => esc_html__( 'Type your content here', 'consult' ),
				'type' => Controls_Manager::TEXTAREA,
				'label_block' => true,
			]
		);
		$this->add_control(
			'projectItems_groups',
			[
				'label' => esc_html__( 'Project Icons', 'consult' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'project_title' => esc_html__( 'Project', 'consult' ),
					],
					
				],
				'fields' =>  $repeater->get_controls(),
				'title_field' => '{{{ project_title }}}',
			]
		);
		$this->end_controls_section();// end: Section
		
		// Project
		$this->start_controls_section(
			'project_section_style',
			[
				'label' => esc_html__( 'project', 'consult' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'project_bg_color',
				'label' => esc_html__( 'Background', 'consult' ),
				'description' => esc_html__( 'Shape Background Color', 'consult' ),
				'types' => [ 'gradient' ],
				'selector' => '{{WRAPPER}} .project-section .projects-grids .grid:after',
			]
		);
	
		$this->end_controls_section();// end: Section
		
		// Title
		$this->start_controls_section(
			'section_title_style',
			[
				'label' => esc_html__( 'Title', 'consult' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'consult' ),
				'name' => 'consult_title_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .project-section .details h3',
			]
		);
		$this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Color', 'consult' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .project-section .details h3' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'title_padding',
			[
				'label' => esc_html__( 'Title Padding', 'consult' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .project-section .details h3' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

	// Content
		$this->start_controls_section(
			'section_content_style',
			[
				'label' => esc_html__( 'Content', 'consult' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'consult' ),
				'name' => 'section_content_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .project-section .details span',
			]
		);
		$this->add_control(
			'content_color',
			[
				'label' => esc_html__( 'Color', 'consult' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .project-section .details span' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		
	}

	/**
	 * Render Project widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	*/
	protected function render() {
		$settings = $this->get_settings_for_display();
		$projectItems_groups = !empty( $settings['projectItems_groups'] ) ? $settings['projectItems_groups'] : [];

		// Turn output buffer on
		ob_start(); ?>

		<div class="project-section">
    		<div class="projects-grids">
		       <?php 	// Group Param Output
							if( is_array( $projectItems_groups ) && !empty( $projectItems_groups ) ){
							foreach ( $projectItems_groups as $each_item ) { 

							$project_title = !empty( $each_item['project_title'] ) ? $each_item['project_title'] : '';
							$project_content = !empty( $each_item['project_content'] ) ? $each_item['project_content'] : '';

							$bg_image = !empty( $each_item['project_image']['id'] ) ? $each_item['project_image']['id'] : '';	

							// Image
							$image_url = wp_get_attachment_url( $bg_image );
							$image_alt = get_post_meta( $bg_image, '_wp_attachment_image_alt', true);

						?>
		        <div class="grid">
		            <div class="img-holder">
		               <?php if( $image_url ) { echo '<img src="'.esc_url( $image_url ).'" alt="'.esc_url( $image_alt ).'">'; } ?>
		            </div>
		            <div class="details">
		            	<?php 
			            	if( $project_content ) { echo '<span class="cat">'.esc_html( $project_content ).'</span>'; }
			            	if( $project_title ) { echo '<h3>'.esc_html( $project_title ).'</h3>'; }
			             ?>
		            </div>
		        </div>
						<?php 
							}
						} 
					?>
		    </div>
		</div> 

		<?php // Return outbut buffer
			echo ob_get_clean();	
		}
	
}