<?php
/*
 * Elementor Consult Service Widget
 * Author & Copyright: helloexpert
*/

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Consult_Service extends Widget_Base{

	/**
	 * Retrieve the widget name.
	*/
	public function get_name(){
		return 'hx-consult_service';
	}

	/**
	 * Retrieve the widget title.
	*/
	public function get_title(){
		return esc_html__( 'Service', 'consult' );
	}

	/**
	 * Retrieve the widget icon.
	*/
	public function get_icon() {
		return 'fa fa-telegram';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	*/
	public function get_categories() {
		return ['consult-elements'];
	}

	/**
	 * Retrieve the list of scripts the Consult Service widget depended on.
	 * Used to set scripts dependencies required to run the widget.
	*/
	public function get_script_depends() {
		return ['hx-consult_service'];
	}
	
	/**
	 * Register Consult Service widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	*/
	protected function _register_controls(){
		
		$this->start_controls_section(
			'section_service',
			[
				'label' => esc_html__( 'Service Options', 'consult' ),
			]
		);
		$repeater = new Repeater();
		$repeater->add_control(
			'service_icon',
			[
				'label' => esc_html__( 'Icon', 'consult' ),
				'type' => \Elementor\Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'default' => [
					'value' => 'fi flaticon-money-bag',
					'library' => 'solid',
				],
			]
		);
		$repeater->add_control(
			'service_title',
			[
				'label' => esc_html__( 'Title Text', 'consult' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Title Text', 'consult' ),
				'placeholder' => esc_html__( 'Type title text here', 'consult' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'service_content',
			[
				'label' => esc_html__( 'Content', 'consult' ),
				'default' => esc_html__( 'your content text', 'consult' ),
				'placeholder' => esc_html__( 'Type your content here', 'consult' ),
				'type' => Controls_Manager::TEXTAREA,
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'service_link',
			[
				'label' => esc_html__( 'link', 'consult' ),
				'default' => esc_html__( '#', 'consult' ),
				'placeholder' => esc_html__( 'Type your link here', 'consult' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
			]
		);
		$this->add_control(
			'serviceItems_groups',
			[
				'label' => esc_html__( 'Service Icons', 'consult' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'service_title' => esc_html__( 'Service', 'consult' ),
					],
					
				],
				'fields' =>  $repeater->get_controls(),
				'title_field' => '{{{ service_title }}}',
			]
		);
		$this->end_controls_section();// end: Section
		
		// Service
		$this->start_controls_section(
			'service_section_style',
			[
				'label' => esc_html__( 'service', 'consult' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'service_section_color',
			[
				'label' => esc_html__( 'Background Color', 'consult' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .services-section .service-grids .grid' => 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->end_controls_section();// end: Section

		//Service Icons

		$this->start_controls_section(
			'section_icon_style',
			[
				'label' => esc_html__( 'Icon', 'consult' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'consult' ),
				'name' => 'consult_icon_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .services-section .service-grids .grid i',
			]
		);
		$this->add_control(
			'icon_color',
			[
				'label' => esc_html__( 'Icon Color', 'consult' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .services-section .service-grids .grid i' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();// end: Section
		
		// Title
		$this->start_controls_section(
			'section_title_style',
			[
				'label' => esc_html__( 'Title', 'consult' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'consult' ),
				'name' => 'consult_title_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .services-section .service-grids .grid h3',
			]
		);
		$this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Color', 'consult' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .services-section .service-grids .grid h3' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'title_padding',
			[
				'label' => esc_html__( 'Title Padding', 'consult' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .services-section .service-grids .grid h3' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

	// Content
		$this->start_controls_section(
			'section_content_style',
			[
				'label' => esc_html__( 'Content', 'consult' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'consult' ),
				'name' => 'section_content_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .services-section .service-grids .grid p',
			]
		);
		$this->add_control(
			'content_color',
			[
				'label' => esc_html__( 'Color', 'consult' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .services-section .service-grids .grid p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		
	}

	/**
	 * Render Service widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	*/
	protected function render() {
		$settings = $this->get_settings_for_display();
		$serviceItems_groups = !empty( $settings['serviceItems_groups'] ) ? $settings['serviceItems_groups'] : [];

		// Turn output buffer on
		ob_start(); ?>

		<div class="services-section">
		    <div class="service-grids clearfix">
		       <?php 	// Group Param Output
							if( is_array( $serviceItems_groups ) && !empty( $serviceItems_groups ) ){
							foreach ( $serviceItems_groups as $each_item ) { 

							$service_title = !empty( $each_item['service_title'] ) ? $each_item['service_title'] : '';
							$service_content = !empty( $each_item['service_content'] ) ? $each_item['service_content'] : '';
							$service_link = !empty( $each_item['service_link'] ) ? $each_item['service_link'] : '';

							$service_icon = !empty( $each_item['service_icon']['value'] ) ? $each_item['service_icon']['value'] : '';
							$service_svg_url = !empty( $each_item['service_icon']['value']['url'] ) ? $each_item['service_icon']['value']['url'] : '';
							$svg_alt = get_post_meta( $service_svg_url , '_wp_attachment_image_alt', true);
							

							if ( $service_link ) {
					      $link_o = '<a href="'. $service_link .'">';
					      $link_c = '</a>';
					    } else {
					      $link_o = '';
					      $link_c = '';
					    }

					    if( $service_link ) { echo $link_o; }
						?>

		        <div class="grid">
		            <div class="icon">
		            		<?php if ( $service_svg_url ) { 
		            			 echo '<img src="'.esc_url( $service_svg_url ).'" alt="'.esc_url( $svg_alt ).'">';
		            		} else {
		            			echo '<i class="'.esc_attr( $service_icon ).'"></i>';
		            		}?>
		            </div>
		            <?php 
		            	if( $service_title ) { echo '<h3>'.esc_html( $service_title ).'</h3>'; }
		            	if( $service_content ) { echo '<p>'.esc_html( $service_content ).'</p>'; }
		             ?>
		        </div>
					<?php 
						if( $service_link ) { echo $link_c; }
						}
					} 
				?>
		    </div>
		</div> 

		<?php // Return outbut buffer
			echo ob_get_clean();	
		}
	
}