<?php
/*
 * Elementor Consult Testimonials Widget
 * Author & Copyright: helloexpert
*/

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Consult_Testimonials extends Widget_Base{

	/**
	 * Retrieve the widget name.
	*/
	public function get_name(){
		return 'consult_testimonials';
	}

	/**
	 * Retrieve the widget title.
	*/
	public function get_title(){
		return esc_html__( 'Testimonials', 'consult' );
	}

	/**
	 * Retrieve the widget icon.
	*/
	public function get_icon() {
		return 'fa fa-file-signature';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	*/
	public function get_categories() {
		return ['consult-elements'];
	}

	/**
	 * Retrieve the list of scripts the Consult Testimonials widget depended on.
	 * Used to set scripts dependencies required to run the widget.
	*/
	public function get_script_depends() {
		return ['consult_testimonials_script'];
	}
	
	/**
	 * Register Consult Testimonials widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	*/
	protected function _register_controls(){
		
		$this->start_controls_section(
			'section_testimonials',
			[
				'label' => esc_html__( 'Testimonials Options', 'consult' ),
			]
		);
		$repeater = new Repeater();
		$repeater->add_control(
			'testimonials_title',
			[
				'label' => esc_html__( 'Title Text', 'consult' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Title Text', 'consult' ),
				'placeholder' => esc_html__( 'Type title text here', 'consult' ),
				'label_block' => true,
			]
		);	
		$repeater->add_control(
			'testimonials_subtitle',
			[
				'label' => esc_html__( 'Sub Title Text', 'consult' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Sub Title Text', 'consult' ),
				'placeholder' => esc_html__( 'Type sub title text here', 'consult' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'testimonials_content',
			[
				'label' => esc_html__( 'Content', 'consult' ),
				'default' => esc_html__( 'your content text', 'consult' ),
				'placeholder' => esc_html__( 'Type your content here', 'consult' ),
				'type' => Controls_Manager::TEXTAREA,
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'testimonials_image',
			[
				'label' => esc_html__( 'Testimonial Image', 'consult' ),
				'type' => Controls_Manager::MEDIA,
				'frontend_available' => true,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'description' => esc_html__( 'Set your image.', 'consult'),
			]
		);
		$this->add_control(
			'testimonialsItems_groups',
			[
				'label' => esc_html__( 'Testimonials Icons', 'consult' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'testimonials_title' => esc_html__( 'Testimonials', 'consult' ),
					],
					
				],
				'fields' =>  $repeater->get_controls(),
				'title_field' => '{{{ testimonials_title }}}',
			]
		);
		$this->end_controls_section();// end: Section
		
		// Testimonials
		$this->start_controls_section(
			'testimonials_section_style',
			[
				'label' => esc_html__( 'Background', 'consult' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'testimonials_section_color',
			[
				'label' => esc_html__( 'Background Color', 'consult' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .testimonials-section .quote' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .testimonials-section .quote:before' => 'border-top-color: {{VALUE}};'
				],
			]
		);
		
		$this->end_controls_section();// end: Section

		//Testimonials Icons

		$this->start_controls_section(
			'section_icon_style',
			[
				'label' => esc_html__( 'Icon', 'consult' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'consult' ),
				'name' => 'consult_icon_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .testimonials-section .client-info .inner:before, .testimonials-section .client-info .inner:after',
			]
		);
		$this->add_control(
			'icon_color',
			[
				'label' => esc_html__( 'Icon Color', 'consult' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .testimonials-section .client-info .inner:before, .testimonials-section .client-info .inner:after' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();// end: Section
		
		// Title
		$this->start_controls_section(
			'section_title_style',
			[
				'label' => esc_html__( 'Title', 'consult' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'consult' ),
				'name' => 'consult_title_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .testimonials-section .client-info h5',
			]
		);
		$this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Color', 'consult' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .testimonials-section .client-info h5' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'title_padding',
			[
				'label' => esc_html__( 'Title Padding', 'consult' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .testimonials-section .client-info h5' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		// Sub Title
		$this->start_controls_section(
			'section_subtitle_style',
			[
				'label' => esc_html__( 'Sub Title', 'consult' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'consult' ),
				'name' => 'consult_subtitle_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .testimonials-section .client-info p',
			]
		);
		$this->add_control(
			'subtitle_color',
			[
				'label' => esc_html__( 'Color', 'consult' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .testimonials-section .client-info p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'subtitle_padding',
			[
				'label' => esc_html__( 'Title Padding', 'consult' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .testimonials-section .client-info p' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

	// Content
		$this->start_controls_section(
			'section_content_style',
			[
				'label' => esc_html__( 'Content', 'consult' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'consult' ),
				'name' => 'section_content_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .testimonials-section .grid p',
			]
		);
		$this->add_control(
			'content_color',
			[
				'label' => esc_html__( 'Color', 'consult' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .testimonials-section .grid p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		
	}

	/**
	 * Render Testimonials widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	*/
	protected function render() {
		$settings = $this->get_settings_for_display();
		$testimonialsItems_groups = !empty( $settings['testimonialsItems_groups'] ) ? $settings['testimonialsItems_groups'] : [];

		// Turn output buffer on
		ob_start(); ?>

		<div class="testimonials-section ">
    	<div class="col col-md-10 col-md-offset-1">
        <div class="testimonial-grids testimonial-slider clearfix">
		       <?php 	// Group Param Output
							if( is_array( $testimonialsItems_groups ) && !empty( $testimonialsItems_groups ) ){
							foreach ( $testimonialsItems_groups as $each_item ) { 

							$testimonials_title = !empty( $each_item['testimonials_title'] ) ? $each_item['testimonials_title'] : '';
							$testimonials_subtitle = !empty( $each_item['testimonials_subtitle'] ) ? $each_item['testimonials_subtitle'] : '';
							$testimonials_content = !empty( $each_item['testimonials_content'] ) ? $each_item['testimonials_content'] : '';
							$bg_image = !empty( $each_item['testimonials_image']['id'] ) ? $each_item['testimonials_image']['id'] : '';

							// Image
							$image_url = wp_get_attachment_url( $bg_image );
							$image_alt = get_post_meta( $bg_image, '_wp_attachment_image_alt', true);
											
						?>
 						<div class="grid">
                <div class="quote">
                    <?php if( $testimonials_content ) { echo '<p>'.esc_html( $testimonials_content ).'</p>'; } ?>
                </div>
                <div class="client-info">
                    <div class="inner">
                        <div class="img-holder">
                            <?php if( $image_url ) { echo '<img src="'.esc_url( $image_url ).'" alt="'.esc_attr( $image_alt ).'">'; } ?>
                        </div>
                        <div class="details">
                             <?php 
		                        	if( $testimonials_title ) { echo '<h5>'.esc_html( $testimonials_title ).'</h5>'; } 
		                        	if( $testimonials_subtitle ) { echo '<p>'.esc_html( $testimonials_subtitle ).'</p>'; }
		                        ?>
                        </div>
                    </div>
                </div>
            </div>
						<?php 
							}
						} 
					?>
		    </div>
		  </div>
		</div> 
		<?php // Return outbut buffer
			echo ob_get_clean();	
		}
	
}