<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package consult
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function consult_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Adds a class of no-sidebar when there is no sidebar present.
	if ( ! is_active_sidebar( 'sidebar-1' ) ) {
		$classes[] = 'no-sidebar';
	}

	return $classes;
}
add_filter( 'body_class', 'consult_body_classes' );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function consult_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
	}
}
add_action( 'wp_head', 'consult_pingback_header' );



// footer widget

if ( ! function_exists( 'consult_widget_init' ) ) {
	function consult_widget_init() {
		if ( function_exists( 'register_sidebar' ) ) {

			// Footer Widgets
			$footer_widgets = get_theme_mod( 'consult_footer_widget_layout', '' );
	    if( $footer_widgets ) {

	      switch ( $footer_widgets ) {
	        case 3:
	          $length = 3;
	        break;

	        case 4:
	          $length = 4;
	        break;

	        default:
	          $length = $footer_widgets;
	        break;
	      }

	      for( $i = 0; $i < $length; $i++ ) {

	        $num = ( $i+1 );

	        register_sidebar( array(
	          'id'            => 'footer-' . $num,
	          'name'          => esc_html__( 'Footer Widget ', 'consult' ). $num,
	          'description'   => esc_html__( 'Appears on footer section.', 'consult' ),
	          'before_widget' => '<div class="widget %2$s">',
	          'after_widget'  => '<div class="clear"></div></div> <!-- end widget -->',
	          'before_title'  => '<div class="widget-title"><h3>',
	          'after_title'   => '</h3></div>'
	        ) );

	      }

	    }
	    // Footer Widgets


		}
	}
	add_action( 'widgets_init', 'consult_widget_init' );
}


/* Widget Layouts */
if ( ! function_exists( 'consult_footer_widgets' ) ) {
  function consult_footer_widgets() {

    $output = '';
    $consult_footer_widget_layout = get_theme_mod( 'consult_footer_widget_layout', '' );

    if( $consult_footer_widget_layout ) {

      switch ( $consult_footer_widget_layout ) {
        case 1: $widget = array('piece' => 1, 'class' => 'col col-lg-12'); break;
        case 2: $widget = array('piece' => 2, 'class' => 'col col-lg-6'); break;
        case 3: $widget = array('piece' => 3, 'class' => 'col col-lg-4'); break;
        case 4: $widget = array('piece' => 4, 'class' => 'col col-lg-3 col-md-3 col-sm-6'); break;
        default : $widget = array('piece' => 4, 'class' => 'col-lg-3'); break;
      }

      for( $i = 1; $i < $widget["piece"]+1; $i++ ) {

        $widget_class = ( isset( $widget["queue"] ) && $widget["queue"] == $i ) ? $widget["layout"] : $widget["class"];

        if (is_active_sidebar('footer-'. $i)) {
          $output .= '<div class="'. $widget_class .'">';
          ob_start();
            dynamic_sidebar( 'footer-'. $i );
          $output .= ob_get_clean();
          $output .= '</div>';
        }

      }
    }

    return $output;

  }
}


/* Compress CSS */
if ( ! function_exists( 'consult_compress_css_lines' ) ) {
  function consult_compress_css_lines( $css ) {
    $css  = preg_replace( '!/\*[^*]*\*+([^/][^*]*\*+)*/!', '', $css );
    $css  = str_replace( ': ', ':', $css );
    $css  = str_replace( array( "\r\n", "\r", "\n", "\t", '  ', '    ', '    ' ), '', $css );
    return $css;
  }
}

/* Inline Style */
global $consult_all_inline_styles;
$consult_all_inline_styles = array();
if( ! function_exists( 'consult_add_inline_style' ) ) {
  function consult_add_inline_style( $style ) {
    global $consult_all_inline_styles;
    array_push( $consult_all_inline_styles, $style );
  }
}

/* Enqueue Inline Styles */
if ( ! function_exists( 'consult_enqueue_inline_styles' ) ) {
  function consult_enqueue_inline_styles() {

    global $consult_all_inline_styles;

    if ( ! empty( array_filter($consult_all_inline_styles) ) ) {
      echo '<style id="consult-inline-style" type="text/css">'. consult_compress_css_lines( join( '', $consult_all_inline_styles ) ) .'</style>';
    }

  }
  add_action( 'wp_footer', 'consult_enqueue_inline_styles' );
}

add_filter('acf/settings/show_admin', '__return_false');